require 'dcell'
require 'dcell/registries/s3_adapter'
require 'optparse'

# The DCell node_id
name = nil

# The local port for the 0MQ communication.
port = nil

# The S3 bucket
bucket = nil

OptionParser.new.tap { |options|
  options.on('-n NAME', 'Node name') do |value|
    name = value
  end
  options.on('-p PORT', 'Node port') do |value|
    port = value.to_i
  end
  options.on('-b BUCKET', 'Bucket name') do |value|
    bucket = value
  end
}.parse(ARGV)

unless bucket and (name or port)
  puts "Missing options. See -h for available options."
  exit 1
end

registry = { :adapter => 's3', :env => 'test', :bucket => bucket }

class TimeServer
  include Celluloid

  def run
    "[#{DCell.me.id}] #{Time.now}"
  end
end

class StatusServer
  include Celluloid

  def run
    "[#{DCell.me.id}] STATUS OK"
  end
end

DCell.start(:id => name, :addr => "tcp://127.0.0.1:#{port}", :registry => registry)

if name == 'master'
  TimeServer.supervise_as :service
else
  StatusServer.supervise_as :service
end

loop do
  puts DCell::Node.all.inspect
  puts DCell::Node.all.shuffle.first[:service].run

  sleep 1
end
